2 ms·
Did you read any of the comments? I did and I am certainly not qualified enough to know if the 17x faster claim holds up at all.
by hahainternet 11y ago
Did you read any of the comments? I did and I am certainly not qualified enough to know if the 17x faster claim holds up at all.
- i_s 11y agoI did now, and the only relevant retort I saw to this specific claim was that it is possible to work around it by using cern.colt.map.OpenIntDoubleHashMap (third party) instead of java.util.HashMap. So someone has worked around the problem by creating an implementation for a specific value type, but as the author explains, that comes with a big loss of genericity compared to the .NET solution.